Module error

Module error 

Interpreter error types and error codes. Interpreter error types matching the Go SDK’s errs package.

Structs

InterpreterError
A script interpreter error with an error code and description.

Enums

InterpreterErrorCode
Error codes for the script interpreter.

Functions

is_error_code
Check if an error has a specific error code.