pub struct InterpreterError {
pub code: InterpreterErrorCode,
pub description: String,
}Expand description
A script interpreter error with an error code and description.
Fields
code: InterpreterErrorCodeThe error code identifying the class of error.
description: StringA human-readable description of the error.
Implementations
Sourceimpl InterpreterError
impl InterpreterError
Sourcepub fn new(code: InterpreterErrorCode, description: String) -> Self
pub fn new(code: InterpreterErrorCode, description: String) -> Self
Create a new interpreter error from an error code and description string.