pub struct ParsedOpcode {
pub opcode: u8,
pub data: Vec<u8>,
}Expand description
A parsed opcode with its data payload.
Fields
opcode: u8The opcode byte value.
data: Vec<u8>The data payload associated with push opcodes (empty for non-push opcodes).
Implementations
Sourceimpl ParsedOpcode
impl ParsedOpcode
Sourcepub fn is_disabled(&self) -> bool
pub fn is_disabled(&self) -> bool
Return true if this opcode is disabled (OP_2MUL, OP_2DIV).
Sourcepub fn always_illegal(&self) -> bool
pub fn always_illegal(&self) -> bool
Return true if this opcode is always illegal (OP_VERIF, OP_VERNOTIF).
Sourcepub fn is_conditional(&self) -> bool
pub fn is_conditional(&self) -> bool
Return true if this opcode is a conditional flow control opcode.
Sourcepub fn requires_tx(&self) -> bool
pub fn requires_tx(&self) -> bool
Return true if this opcode requires a transaction context to execute.
Sourcepub fn enforce_minimum_data_push(&self) -> Result<(), InterpreterError>
pub fn enforce_minimum_data_push(&self) -> Result<(), InterpreterError>
Check that push uses minimal encoding.
Sourcepub fn canonical_push(&self) -> bool
pub fn canonical_push(&self) -> bool
Check if this is a canonical push (matches the smallest push opcode).