is_push_data

Function is_push_data 

pub fn is_push_data(op: u8) -> bool
Check if an opcode is a push data opcode (OP_DATA_1..OP_PUSHDATA4).

Arguments

  • op - The opcode byte value.

Returns

true if the opcode pushes data onto the stack.