ScriptFlags

Struct ScriptFlags 

pub struct ScriptFlags(pub u32);
Script verification flags controlling interpreter behavior.

Tuple Fields

0: u32

Implementations

Source

impl ScriptFlags

pub const NONE: ScriptFlags

No flags set; accept all transactions.

pub const BIP16: ScriptFlags

Evaluate P2SH (BIP16) subscripts.

pub const STRICT_MULTI_SIG: ScriptFlags

Enforce strict multisig dummy element (must be OP_0).

pub const DISCOURAGE_UPGRADABLE_NOPS: ScriptFlags

Discourage use of upgradable NOP opcodes (NOP1-NOP10).

pub const VERIFY_CHECKLOCKTIMEVERIFY: ScriptFlags

Enforce OP_CHECKLOCKTIMEVERIFY (BIP65).

pub const VERIFY_CHECKSEQUENCEVERIFY: ScriptFlags

Enforce OP_CHECKSEQUENCEVERIFY (BIP112).

pub const VERIFY_CLEAN_STACK: ScriptFlags

Require exactly one element on the stack after execution.

pub const VERIFY_DER_SIGNATURES: ScriptFlags

Require strict DER encoding for signatures.

pub const VERIFY_LOW_S: ScriptFlags

Require the S value in signatures to be in the lower half of the curve order.

pub const VERIFY_MINIMAL_DATA: ScriptFlags

Require minimal encoding for data pushes.

pub const VERIFY_NULL_FAIL: ScriptFlags

Require failed CHECK(MULTI)SIG operations to have empty signatures.

pub const VERIFY_SIG_PUSH_ONLY: ScriptFlags

Require the unlocking script to contain only push opcodes.

pub const ENABLE_SIGHASH_FORKID: ScriptFlags

Enable SIGHASH_FORKID replay protection (BSV-specific).

pub const VERIFY_STRICT_ENCODING: ScriptFlags

Require strict signature and public key encoding.

pub const VERIFY_BIP143_SIGHASH: ScriptFlags

Use BIP143-style sighash algorithm for signature verification.

pub const UTXO_AFTER_GENESIS: ScriptFlags

Indicates the UTXO being spent was created after the genesis upgrade.

pub const VERIFY_MINIMAL_IF: ScriptFlags

Require OP_IF/OP_NOTIF arguments to be exactly empty or 0x01.

pub fn has_flag(self, flag: ScriptFlags) -> bool

Return true if the given flag is set in this flags value.

pub fn has_any(self, flags: &[ScriptFlags]) -> bool

Return true if any of the given flags are set in this flags value.

pub fn add_flag(&mut self, flag: ScriptFlags)

Set the given flag bits in this flags value.